==> haskell-edit-distance-0.2.2.1-209-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-edit-distance.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 edit-distance
version:              0.2.2.1
visibility:           public
id:                   edit-distance-0.2.2.1-5WaZt6w1BPlGXI4XT98xMl
key:                  edit-distance-0.2.2.1-5WaZt6w1BPlGXI4XT98xMl
license:              BSD-3-Clause
copyright:            (c) 2008-2013 Maximilian Bolinbroke
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://github.com/phadej/edit-distance
synopsis:
    Levenshtein and restricted Damerau-Levenshtein edit distances

description:
    Optimized edit distances for fuzzy matching, including Levenshtein and restricted Damerau-Levenshtein algorithms.

category:             Algorithms
abi:                  7aee8b284f6ff8ca1e8fdc00981e0838
exposed:              True
exposed-modules:      Text.EditDistance
hidden-modules:
    Text.EditDistance.EditCosts Text.EditDistance.SquareSTUArray
    Text.EditDistance.STUArray Text.EditDistance.Bits
    Text.EditDistance.MonadUtilities Text.EditDistance.ArrayUtilities

import-dirs:          /usr/lib/ghc-9.2.8/site-local/edit-distance-0.2.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/edit-distance-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-edit-distance
hs-libraries:         HSedit-distance-0.2.2.1-5WaZt6w1BPlGXI4XT98xMl
depends:
    array-0.5.4.0 base-4.16.4.0 containers-0.6.5.1
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh

haddock-interfaces:
    /usr/share/doc/haskell-edit-distance/html/edit-distance.haddock

haddock-html:         /usr/share/doc/haskell-edit-distance/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edit-distance-0.2.2.1-238.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-edit-distance.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 edit-distance
version:              0.2.2.1
visibility:           public
id:                   edit-distance-0.2.2.1-B8TDifutoaz7kPArdeAb9M
key:                  edit-distance-0.2.2.1-B8TDifutoaz7kPArdeAb9M
license:              BSD-3-Clause
copyright:            (c) 2008-2013 Maximilian Bolinbroke
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://github.com/phadej/edit-distance
synopsis:
    Levenshtein and restricted Damerau-Levenshtein edit distances

description:
    Optimized edit distances for fuzzy matching, including Levenshtein and restricted Damerau-Levenshtein algorithms.

category:             Algorithms
abi:                  322773debc3325dc66c59e531bd3edf9
exposed:              True
exposed-modules:      Text.EditDistance
hidden-modules:
    Text.EditDistance.EditCosts Text.EditDistance.SquareSTUArray
    Text.EditDistance.STUArray Text.EditDistance.Bits
    Text.EditDistance.MonadUtilities Text.EditDistance.ArrayUtilities

import-dirs:          /usr/lib/ghc-9.4.8/site-local/edit-distance-0.2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/edit-distance-0.2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/edit-distance-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-edit-distance
hs-libraries:         HSedit-distance-0.2.2.1-B8TDifutoaz7kPArdeAb9M
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    random-1.2.1.2-5Y3bNr2vhgE1UbXPPVLWyj

haddock-interfaces:
    /usr/share/doc/haskell-edit-distance/html/edit-distance.haddock

haddock-html:         /usr/share/doc/haskell-edit-distance/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
